Class: CoreLibrary::GlobalConfiguration
- Inherits:
-
Object
- Object
- CoreLibrary::GlobalConfiguration
- Defined in:
- lib/apimatic-core/configurations/global_configuration.rb
Overview
A class to hold the global configurations for the core library. This class is initiated from the SDK.
Instance Attribute Summary collapse
-
#client_configuration ⇒ Object
readonly
Returns the value of attribute client_configuration.
Instance Method Summary collapse
-
#add_useragent_in_headers(user_agent, agent_parameters) ⇒ Object
Updates the user agent template with the provided parameters and adds user agent in the global_headers.
-
#additional_header(key, value) ⇒ GlobalConfiguration
The setter for a additional header to be attached with all requests.
-
#additional_headers(additional_headers) ⇒ GlobalConfiguration
The setter for the additional headers to be attached with all requests.
-
#auth_managers(auth_managers) ⇒ GlobalConfiguration
The setter for the auth managers.
-
#base_uri_executor(base_uri_executor) ⇒ GlobalConfiguration
The setter for the base URI extractor callable.
-
#get_additional_headers ⇒ Hash
The getter for the additional headers.
-
#get_auth_managers ⇒ Hash
The getter for the auth managers.
-
#get_base_uri_executor ⇒ Callable
The getter for the base URI extractor.
-
#get_global_errors ⇒ Hash
The getter for the global errors.
-
#get_global_headers ⇒ Hash
The getter for the global headers.
-
#get_sdk_module ⇒ Module
Getter for the current SDK module the core library is being used for.
-
#global_errors(global_errors) ⇒ GlobalConfiguration
The setter for the global errors.
-
#global_header(key, value) ⇒ GlobalConfiguration
The setter for a global header to be attached with all requests.
-
#global_headers(global_headers) ⇒ GlobalConfiguration
The setter for the global headers to be attached with all requests.
-
#initialize(client_configuration: HttpClientConfiguration.new) ⇒ GlobalConfiguration
constructor
Initializes a new instance of GlobalConfiguration.
-
#sdk_module(sdk_module) ⇒ GlobalConfiguration
Sets the current SDK module core library is being used for.
-
#should_symbolize_hash ⇒ Boolean
The setter for the flag of wrapping the body parameters in a hash.
-
#symbolize_hash(symbolize_hash) ⇒ GlobalConfiguration
The setter for the flag of symbolizing hash while deserialization.
-
#user_agent(user_agent, agent_parameters: {}) ⇒ GlobalConfiguration
The setter for the user agent information to be attached with all requests.
Constructor Details
#initialize(client_configuration: HttpClientConfiguration.new) ⇒ GlobalConfiguration
Initializes a new instance of GlobalConfiguration.
8 9 10 11 12 13 14 15 16 17 |
# File 'lib/apimatic-core/configurations/global_configuration.rb', line 8 def initialize(client_configuration: HttpClientConfiguration.new) @client_configuration = client_configuration @global_errors = {} @global_headers = {} @additional_headers = {} @auth_managers = {} @base_uri_executor = nil @sdk_module = nil @symbolize_hash = false end |
Instance Attribute Details
#client_configuration ⇒ Object (readonly)
Returns the value of attribute client_configuration.
4 5 6 |
# File 'lib/apimatic-core/configurations/global_configuration.rb', line 4 def client_configuration @client_configuration end |
Instance Method Details
#add_useragent_in_headers(user_agent, agent_parameters) ⇒ Object
Updates the user agent template with the provided parameters and adds user agent in the global_headers.
146 147 148 149 150 151 152 |
# File 'lib/apimatic-core/configurations/global_configuration.rb', line 146 def add_useragent_in_headers(user_agent, agent_parameters) if !agent_parameters.nil? && agent_parameters.any? user_agent = ApiHelper.update_user_agent_value_with_parameters(user_agent, agent_parameters).gsub(' ', ' ') end @global_headers['user-agent'] = user_agent unless user_agent.nil? end |
#additional_header(key, value) ⇒ GlobalConfiguration
The setter for a additional header to be attached with all requests.
81 82 83 84 |
# File 'lib/apimatic-core/configurations/global_configuration.rb', line 81 def additional_header(key, value) @additional_headers[key] = value self end |
#additional_headers(additional_headers) ⇒ GlobalConfiguration
The setter for the additional headers to be attached with all requests.
72 73 74 75 |
# File 'lib/apimatic-core/configurations/global_configuration.rb', line 72 def additional_headers(additional_headers) @additional_headers = additional_headers self end |
#auth_managers(auth_managers) ⇒ GlobalConfiguration
The setter for the auth managers.
95 96 97 98 |
# File 'lib/apimatic-core/configurations/global_configuration.rb', line 95 def auth_managers(auth_managers) @auth_managers = auth_managers self end |
#base_uri_executor(base_uri_executor) ⇒ GlobalConfiguration
The setter for the base URI extractor callable.
118 119 120 121 |
# File 'lib/apimatic-core/configurations/global_configuration.rb', line 118 def base_uri_executor(base_uri_executor) @base_uri_executor = base_uri_executor self end |
#get_additional_headers ⇒ Hash
The getter for the additional headers.
88 89 90 |
# File 'lib/apimatic-core/configurations/global_configuration.rb', line 88 def get_additional_headers @additional_headers end |
#get_auth_managers ⇒ Hash
The getter for the auth managers.
102 103 104 |
# File 'lib/apimatic-core/configurations/global_configuration.rb', line 102 def get_auth_managers @auth_managers end |
#get_base_uri_executor ⇒ Callable
The getter for the base URI extractor.
125 126 127 |
# File 'lib/apimatic-core/configurations/global_configuration.rb', line 125 def get_base_uri_executor @base_uri_executor end |
#get_global_errors ⇒ Hash
The getter for the global errors.
29 30 31 |
# File 'lib/apimatic-core/configurations/global_configuration.rb', line 29 def get_global_errors @global_errors end |
#get_global_headers ⇒ Hash
The getter for the global headers.
65 66 67 |
# File 'lib/apimatic-core/configurations/global_configuration.rb', line 65 def get_global_headers @global_headers end |
#get_sdk_module ⇒ Module
Getter for the current SDK module the core library is being used for.
42 43 44 |
# File 'lib/apimatic-core/configurations/global_configuration.rb', line 42 def get_sdk_module @sdk_module end |
#global_errors(global_errors) ⇒ GlobalConfiguration
The setter for the global errors.
22 23 24 25 |
# File 'lib/apimatic-core/configurations/global_configuration.rb', line 22 def global_errors(global_errors) @global_errors = global_errors self end |
#global_header(key, value) ⇒ GlobalConfiguration
The setter for a global header to be attached with all requests.
58 59 60 61 |
# File 'lib/apimatic-core/configurations/global_configuration.rb', line 58 def global_header(key, value) @global_headers[key] = value self end |
#global_headers(global_headers) ⇒ GlobalConfiguration
The setter for the global headers to be attached with all requests.
49 50 51 52 |
# File 'lib/apimatic-core/configurations/global_configuration.rb', line 49 def global_headers(global_headers) @global_headers = global_headers self end |
#sdk_module(sdk_module) ⇒ GlobalConfiguration
Sets the current SDK module core library is being used for.
35 36 37 38 |
# File 'lib/apimatic-core/configurations/global_configuration.rb', line 35 def sdk_module(sdk_module) @sdk_module = sdk_module self end |
#should_symbolize_hash ⇒ Boolean
The setter for the flag of wrapping the body parameters in a hash.
139 140 141 |
# File 'lib/apimatic-core/configurations/global_configuration.rb', line 139 def should_symbolize_hash @symbolize_hash end |
#symbolize_hash(symbolize_hash) ⇒ GlobalConfiguration
The setter for the flag of symbolizing hash while deserialization.
132 133 134 135 |
# File 'lib/apimatic-core/configurations/global_configuration.rb', line 132 def symbolize_hash(symbolize_hash) @symbolize_hash = symbolize_hash self end |
#user_agent(user_agent, agent_parameters: {}) ⇒ GlobalConfiguration
The setter for the user agent information to be attached with all requests.
110 111 112 113 |
# File 'lib/apimatic-core/configurations/global_configuration.rb', line 110 def user_agent(user_agent, agent_parameters: {}) add_useragent_in_headers(user_agent, agent_parameters) self end |